@@ -22,32 +22,6 @@
  +-------------------------------------------------------------------------+
 */
 
-function upgrade_to_1_1_17() {
-	// Finalize fix to LDAP authentication
-	db_install_execute('UPDATE user_auth SET realm=3 WHERE realm=1');
-
-	if (!db_column_exists('data_source_profiles_rra', 'timespan')) {
-		db_install_execute('ALTER TABLE data_source_profiles_rra
-			ADD COLUMN timespan int(10) unsigned NOT NULL DEFAULT "0"');
-
-		$rras = db_fetch_assoc("SELECT * FROM data_source_profiles_rra");
-
-		if (cacti_sizeof($rras)) {
-			foreach($rras as $rra) {
-				$interval = db_fetch_cell_prepared('SELECT step
-					FROM data_source_profiles
-					WHERE id = ?',
-					array($rra['data_source_profile_id']));
-
-				$timespan = $rra['steps'] * $interval * $rra['rows'];
-
-				$timespan = get_nearest_timespan($timespan);
-
-				db_install_execute('UPDATE data_source_profiles_rra
-					SET timespan = ?
-					WHERE id = ?',
-					array($timespan, $rra['id']));
-			}
-		}
-	}
+function upgrade_to_1_0_4() {
+	db_install_add_key('poller_output_boost', 'KEY', 'PRIMARY', array('local_data_id', 'time', 'rrd_name'), 'BTREE');
 }
